@@ -1,4 +1,4 @@
-cshp <- function(date=NA) {
+cshp <- function(date=NA, useGW=TRUE) {
 		
 	# check input
   	if (!is.na(date) && !inherits(date, "Date")) {
@@ -17,11 +17,17 @@ cshp <- function(date=NA) {
 	
 	if (is.na(date)) {
 		cshp.full
+	} else if (useGW) {
+		startdate <- as.Date(paste(cshp.full$GWSYEAR, cshp.full$GWSMONTH, cshp.full$GWSDAY, sep="-"))
+		enddate <- as.Date(paste(cshp.full$GWEYEAR, cshp.full$GWEMONTH, cshp.full$GWEDAY, sep="-"))
+		cshp.part <- cshp.full[startdate < date & enddate >= date,]
+		cshp.part
 	} else {
 		startdate <- as.Date(paste(cshp.full$COWSYEAR, cshp.full$COWSMONTH, cshp.full$COWSDAY, sep="-"))
 		enddate <- as.Date(paste(cshp.full$COWEYEAR, cshp.full$COWEMONTH, cshp.full$COWEDAY, sep="-"))
 		cshp.part <- cshp.full[startdate < date & enddate >= date,]
 		cshp.part
 	}	
+
 }
 
